import React, { ReactElement } from 'react';
import './index.less';
import './style/button.css';
import './style/empty.css';
import './style/input.css';
import './style/message.css';
import './style/modal.css';
import './style/spin.css';
import './style/tooltip.css';
export declare type LayoutItem = {
    w: number;
    h: number;
    x: number;
    y: number;
    i: string;
    minW: number;
    maxW: number;
    minH: number;
    maxH: number;
};
export declare type LayoutsIF = LayoutItem[];
export interface widgetIF {
    name: string;
    description: string;
    tags: string[];
    component: ReactElement;
    configComponent: ReactElement;
    maxLength: number;
    snapShot: ImageBitmapSource;
    icon: ReactElement;
    iconBackground: string;
    size: {
        defaultWidth: number;
        defaultHeight: number;
        maxWidth: number;
        maxHeight: number;
        minWidth: number;
        minHeight: number;
    };
    [key: string]: any;
}
interface widgetsIF {
    [key: string]: widgetIF;
}
export interface Dashboard {
    widgets: widgetsIF;
    editMode?: boolean;
    defaultLayout?: LayoutsIF;
    widgetWrapClassName?: string;
    widgetWrapStyle?: React.CSSProperties;
    layout?: LayoutsIF;
    minHeight?: number;
    maxWidgetLength?: number;
    toolbar?: boolean;
    storageKey?: string;
    onLayoutChange?: (layout: LayoutsIF) => void;
    onReset?: (dirtyCurrentLayout: LayoutsIF, currentLayout: LayoutItem) => void;
    onRemoveWidget?: (widget: widgetIF, dirtyCurrentLayout: LayoutsIF, currentLayout: LayoutsIF) => void;
    onAddWidget?: (widget: widgetIF, dirtyCurrentLayout: LayoutsIF, currentLayout: LayoutsIF) => void;
    onReload?: (currentLayout: LayoutsIF) => void;
    onCancelEdit?: (dirtyCurrentLayout: LayoutsIF, currentLayout: LayoutItem) => void;
    onEdit?: (currentLayout: LayoutsIF) => void;
    onSave?: (currentLayout: LayoutsIF) => void;
    onRevert?: (dirtyCurrentLayout: LayoutsIF, currentLayout: LayoutItem) => void;
    [key: string]: any;
}
declare const Dashboard: React.ForwardRefExoticComponent<Pick<Dashboard, keyof Dashboard> & React.RefAttributes<unknown>>;
export default Dashboard;
